@@ -230,6 +230,7 @@ class DbSync:
             self.logger.error("Invalid configuration:\n   * {}".format('\n   * '.join(config_errors)))
             sys.exit(1)
 
+        aws_profile = self.connection_config.get('aws_profile') or os.environ.get('AWS_PROFILE')
         aws_access_key_id = self.connection_config.get('aws_access_key_id') or os.environ.get('AWS_ACCESS_KEY_ID')
         aws_secret_access_key = self.connection_config.get('aws_secret_access_key') or os.environ.get('AWS_SECRET_ACCESS_KEY')
         aws_session_token = self.connection_config.get('aws_session_token') or os.environ.get('AWS_SESSION_TOKEN')
@@ -249,7 +250,7 @@ class DbSync:
             self.connection_config['aws_secret_access_key'] = credentials.secret_key
             self.connection_config['aws_session_token'] = credentials.token
         else:
-            aws_session = boto3.session.Session()
+            aws_session = boto3.session.Session(profile_name=aws_profile)
 
         self.s3 = aws_session.client('s3')
         self.skip_updates = self.connection_config.get('skip_updates', False)
@@ -379,12 +380,14 @@ class DbSync:
 
         # Generating key in S3 bucket
         bucket = self.connection_config['s3_bucket']
+        s3_acl = self.connection_config.get('s3_acl')
         s3_key_prefix = self.connection_config.get('s3_key_prefix', '')
         s3_key = "{}pipelinewise_{}{}".format(s3_key_prefix, stream, suffix)
 
         self.logger.info("Target S3 bucket: {}, local file: {}, S3 key: {}".format(bucket, file, s3_key))
 
-        self.s3.upload_file(file, bucket, s3_key)
+        extra_args = {'ACL': s3_acl} if s3_acl else None
+        self.s3.upload_file(file, bucket, s3_key, ExtraArgs=extra_args)
 
         return s3_key
 
